Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Page
Library
Module
Module type
Parameter
Class
Class type
PLUGIN.Commandtype tags = Tags.ttype pathname = Pathname.tThe type t provides some basic combinators and command primitives. Other commands can be made of command specifications (spec).
and spec = | NNo operation.
*)| S of spec listA sequence. This gets flattened in the last stages
*)| A of stringAn atom.
*)| P of pathnameA pathname.
*)| Px of pathnameA pathname, that will also be given to the call_with_target hook.
*)| Sh of stringA bit of raw shell code, that will not be escaped.
*)| T of tagsA set of tags, that describe properties and some semantics information about the command, afterward these tags will be replaced by command specs (flags for instance).
| V of stringA virtual command, that will be resolved at execution using resolve_virtuals
| Quote of specA string that should be quoted like a filename but isn't really one.
*)The type for command specifications. That is pieces of command.
val atomize : string list -> specWill convert a string list to a list of atoms by adding A constructors.
val atomize_paths : string list -> specWill convert a string list to a list of paths by adding P constructors.
val execute : ?quiet:bool -> ?pretend:bool -> t -> unitRun the command.
val execute_many :
?quiet:bool ->
?pretend:bool ->
t list ->
(bool list * exn) optionRun the commands in the given list, if possible in parallel. See the module Ocamlbuild_executor.
val setup_virtual_command_solver : string -> (unit -> spec) -> unitsetup_virtual_command_solver virtual_command solver the given solver can raise Not_found if it fails to find a valid command for this virtual command.
Search the given command in the command path and return its absolute pathname.
Simplify a command by flattening the sequences and resolving the tags into command-line options.
val print : Format.formatter -> t -> unitPrint a command (the format is not suitable to running the command).
val to_string : t -> stringConvert a command to a string (same format as print).
val string_of_command_spec : spec -> stringBuild a string representation of a command that can be passed to the system calls.